/*
 * aboutdialog.cpp
 * ---------------
 * Begin
 *   2007-08-26
 *
 * Last modified
 *   $Date: 2008/11/05 08:42:40 $
 *   $Revision: 1.9 $
 *
 * Copyright
 *   (C) 2007-2014 Guido Scholz <gscholz@users.sourceforge.net>
 *
 * Description
 *   Dialog window to display program information
 *
 * License
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 2 of the License, or
 *   (at your option) any later version.
 */

#include <QFont>
#include <QGroupBox>
#include <QPushButton>
#include <QLayout>
#include <QLabel>
#include <QPixmap>
#include <QVBoxLayout>

#include "aboutdialog.h"

#ifdef WIN32
#include "config_w32.h"
#else
#include "config.h"
#endif

/* application icon */
#include "../icons/spdrs60_48.xpm"


AboutDialog::AboutDialog(QWidget* parent): QDialog(parent)
{
    setModal(true);
    setObjectName("AboutDialog");
    setWindowTitle(tr("About %1").arg(PACKAGE));

    QVBoxLayout* baseLayout = new QVBoxLayout();
    baseLayout->setObjectName("baseLayout");
    baseLayout->setSpacing(10);
    setLayout(baseLayout);

    QLabel* label;

    // first line: pixmap, program name, version
    QHBoxLayout* pixmapLayout = new QHBoxLayout();
    pixmapLayout->setObjectName("pixmapLayout");
    pixmapLayout->setSpacing(20);
    baseLayout->addLayout(pixmapLayout);
    label = new QLabel();
    label->setObjectName("pixmapLabel");
    label->setPixmap(QPixmap(spdrs60_48_xpm));
    pixmapLayout->addWidget(label);

    label = new QLabel(PACKAGE_STRING);
    label->setObjectName("appLabel");
    pixmapLayout->addWidget(label);
    QFont font;
    font.setPointSize(18);
    font.setWeight(QFont::Bold);
    label->setFont(font);

    pixmapLayout->addStretch();

    // second line: description
    label = new QLabel(tr(
                "spdrs60 is a SRCP client to control digital model railways.\n"
                "Visual appearance and usage comply to the original SpDrS60\n"
                "switchbox (Spurplandrucktastenstellwerk Bauart Siemens 60)\n"
                "of the German national railroad company. spdrs60 needs a\n"
                "SRCP server (e.g. erddcd or srcpd) as hardware link."));
    label->setObjectName("descLabel");
    baseLayout->addWidget(label);

    // third line: web link
    label = new QLabel("http://spdrs60.sourceforge.net/");
    label->setObjectName("webLabel");
    baseLayout->addWidget(label);


    // authors groupbox
    QGroupBox* authorGB = new QGroupBox(tr("Authors"));
    authorGB->setObjectName("authorsGB");
    QVBoxLayout *vbox = new QVBoxLayout;
    vbox->setObjectName("vbox");
    authorGB->setLayout(vbox);
    baseLayout->addWidget(authorGB);

    label = new QLabel("(C) 1999-2003 Stefan Preis <stefan.preis@wdr.de>");
    vbox->addWidget(label);

    label = new QLabel("(C) 2004-2016 Guido Scholz "
            "<gscholz@users.sourceforge.net>");
    vbox->addWidget(label);

    // contributors groupbox, names in two vertical columns
    QGroupBox* contribGB = new QGroupBox(tr("Contributors"));
    contribGB->setObjectName("contribGB");
    baseLayout->addWidget(contribGB);

    QHBoxLayout *hbox = new QHBoxLayout;
    hbox->setObjectName("hbox");

    QVBoxLayout *vboxl = new QVBoxLayout;
    vboxl->setSpacing(6);
    vboxl->setObjectName("vboxl");
    hbox->addLayout(vboxl);

    QVBoxLayout *vboxr = new QVBoxLayout;
    vboxr->setSpacing(6);
    vboxr->setObjectName("vboxr");
    hbox->addLayout(vboxr);

    contribGB->setLayout(hbox);

    label = new QLabel("Dirk Armbrust");
    vboxl->addWidget(label);
    label = new QLabel("Klaus Mannweiler");
    vboxl->addWidget(label);
    label = new QLabel("Sven Roth");
    vboxl->addWidget(label);
    label = new QLabel(QString::fromUtf8("David Rütti"));
    vboxl->addWidget(label);
    label = new QLabel(QString::fromUtf8("André Schenk"));
    vboxl->addWidget(label);
    vboxl->addStretch();

    label = new QLabel("Ullrich Schicke");
    vboxr->addWidget(label);
    label = new QLabel(QString::fromUtf8("Björn Schließmann"));
    vboxr->addWidget(label);
    label = new QLabel(QString::fromUtf8("Rüdiger Seidel"));
    vboxr->addWidget(label);
    label = new QLabel("Dietmar Toelg");
    vboxr->addWidget(label);
    vboxr->addStretch();

    // OK button
    QHBoxLayout* buttonLayout = new QHBoxLayout();
    buttonLayout->setSpacing(6);
    buttonLayout->setObjectName("buttonLayout");
    baseLayout->addLayout(buttonLayout);
    buttonLayout->addStretch();

    QPushButton* okPB = new QPushButton(tr("OK"));
    buttonLayout->addWidget(okPB);
    okPB->setDefault(true);
    connect(okPB, SIGNAL(clicked()), this, SLOT(accept()));

    buttonLayout->addStretch();
}

