/***************************************************************************
                           main.cpp
                           version 0.5.3 $Revision: 1.22 $
                           -------------------------------
    copyright            : (C) 1999-2003 by Stefan Preis
                         : (C) 2004-2008 Guido Scholz
    email                : guido.scholz@bayernline.de
    last modified        : $Date: 2009-03-18 17:14:03 $
***************************************************************************/

/**************************************************************************
 *                                                                        *
 *  This program is free software; you can redistribute it and/or modify  *
 *  it under the terms of the GNU General Public License as published by  *
 *  the Free Software Foundation; either version 2 of the License, or     *
 *  (at your option) any later version.                                   *
 *                                                                        *
 **************************************************************************/

/**************************************************************************
   This file is the main file and handles all basic setting of a Qt-
   application and stores the command line arguments
 **************************************************************************/

#include <QApplication>
#include <QString>
#include <QLibraryInfo>
#include <QLocale>
#include <QTranslator>

#ifdef WIN32
#include "config_w32.h"
#else
#include "config.h"
#endif

#include "mainwindow.h"


int main(int argc, char* argv[])
{
   QApplication a(argc, argv);

   // translator for Qt library strings
   QTranslator qtTr(0);
   QLocale loc = QLocale::system();

   if (qtTr.load(QString("qt_") + loc.name(),
               QLibraryInfo::location(QLibraryInfo::TranslationsPath)))
       a.installTranslator(&qtTr);
   else
       qWarning("No Qt translation for locale '%s' found.",
               loc.name().toUtf8().constData());

   // translator for application strings
   QTranslator spdrs60Tr(0);

   if (spdrs60Tr.load(QString("spdrs60_") + loc.name(), TRANSLATIONSDIR))
       a.installTranslator(&spdrs60Tr);
   else
       qWarning("No spdrs60 translation for locale '%s' in '%s' found.",
               loc.name().toUtf8().constData(), TRANSLATIONSDIR);

   MainWindow* spdrs60Window = new MainWindow();
   Q_CHECK_PTR(spdrs60Window);
   spdrs60Window->setWindowTitle(PACKAGE);
   spdrs60Window->resize(720, 480);

   //necessary for "-geometry" command-line option
   //a.setMainWidget(spdrs60Window);
   spdrs60Window->show();

   /*only the first application window autoloads a layoutfile*/
   //int ac = qApp->argc();

   if (argc == 1)
       spdrs60Window->readAutoloadFile();
   else {
       spdrs60Window->openFile(argv[1]);
       // loop over all arguments -> open more application windows
       if (argc > 2)
           for (int i = 2; i < argc; i++)
               spdrs60Window->openFileWindow(argv[i]);
   }

   // when the last window is closed, the application should quit
   a.connect(&a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()));

   return a.exec();
}

